@@ -51,6 +51,7 @@ class driver(object):
             options.arguments.extend(["--no-sandbox", "--test-type"])
         if profile["browser"]["headless"]:
             options.add_argument('--headless=chrome')
+            options.add_argument("--blink-settings=imagesEnabled=false")  # disable loading Images
         if profile["browser"]["touch_events"]:
             options.add_argument("--touch-events=enabled")
         if profile["browser"]["app"]:
@@ -220,7 +221,7 @@ class driver(object):
 
     # set force darkmode
     def set_darkmode(self, enabled=True, mobile=True) -> (bool, bool):
-        if not mobile:
+        if not mobile and enabled:
             warnings.warn('darkmode might look weird without mobile_view!')
         else:
             return self.driver.execute_cdp_cmd('Emulation.setAutoDarkModeOverride',
